@@ -26,7 +26,7 @@ except:
 	_c = False
 
 __all__ = ['status']
-__version__ = '3.1.2'
+__version__ = '3.3.0'
 
 if hasattr(_sys, 'runningPPF'):
 	PyProtFramework = True
@@ -43,6 +43,11 @@ else:
 if _os.path.split(_os.path.split(__file__)[0])[1] == 'lightprot':
 	status.append('light')
 	__version__ = __version__.replace('unofficial', 'light')
+	try:
+		_prt = __import__('prot')
+		status.append('haveProt')
+	except:
+		_prt = None
 
 Empty = 'empty'
 
@@ -115,6 +120,7 @@ settingVals = {
 				'ui':'normal',
 				'orderedBuiltinList':'on',
 				'saveDatabase':'off',
+				'colorize':'on',
 				'printMsgPrefix':'',
 				'printMsgColor':''
 				}
@@ -122,6 +128,7 @@ settingVals = {
 settingChoices = {
 					'ui':['verysmall', 'small', 'normal'],
 					'orderedBuiltinList':['off', 'on'],
+					'colorize':['off', 'on'],
 					'saveDatabase':['off', 'on'],
 					'printMsgColor':[color for color in colors['foreground']]
 					}
@@ -350,6 +357,11 @@ def runAsMain(args=None):
 @appendAll
 @addBuiltins
 def printMsg(msg='', color=None, end='\n', file=None, colorize=True, prefix=True):
+	global _c
+	if 'light' in status and 'haveProt' in status and _prt is not None:
+		settings.colorize = _prt.settings.colorize
+	if settings.colorize == 'off':
+		_c = False
 	if prefix and settings.printMsgPrefix:
 		msg = str(settings.printMsgPrefix) + str(msg)
 	else:
@@ -359,7 +371,9 @@ def printMsg(msg='', color=None, end='\n', file=None, colorize=True, prefix=True
 	elif settings.printMsgColor:
 		msg = '-' + settings.printMsgColor + msg + '*end'
 	if colorize:
-		if not _os.name == 'nt' or _c:
+		if settings.colorize == 'off':
+			msg = cleanColor(msg)
+		elif not _os.name == 'nt' or _c:
 			msg = insertColor(msg)
 		else:
 			msg = cleanColor(msg)
@@ -422,6 +436,60 @@ def netScan(port=80, timeout=0.5):
 				hostsAvail.append((host, p))
 	return hostsAvail
 
+@appendAll
+@addBuiltins
+class Matrix(list):
+	def __getitem__(self, key):
+		if type(key) == int:
+			return list.__getitem__(self, key)
+		else:
+			res = self.get(key, default=Empty)
+			if res == Empty:
+				raise KeyError(key)
+			return res
+
+	def __setitem__(self, key, value):
+		self._checkValue(value)
+		if type(key) == int:
+			list.__setitem__(self, key, value)
+		else:
+			self.append([key, value])
+
+	def __init__(self, value=[]):
+		try:
+			if value:
+				self._checkValue(value)
+		except:
+			for v in value:
+				self._checkValue(v)
+		list.__init__(self, value)
+
+	def _checkValue(self, value):
+		if type(value) in [list, tuple, Matrix] and len(value) == 2:
+			return True
+		raise ValueError('value must be object of Matrix, list or tuple classes and should have only two members')
+
+	def append(self, value):
+		self._checkValue(value)
+		list.append(self, value)
+
+	def __delitem__(self, key):
+		if type(key) == int:
+			list.__delitem__(self, key)
+		for k in self:
+			try:
+				if k[0] == key:
+					self.remove(k)
+			except: pass
+
+	def get(self, key, default=None):
+		for k in self:
+			try:
+				if k[0] == key:
+					return k[1]
+			except: pass
+		return default
+
 @appendAll
 def rst2html(path, subdirs=False):
 	if _pf is None:
@@ -453,10 +521,10 @@ def dict2matrix(obj):
 	matrix = []
 	for m in obj:
 		if type(obj[m]) == dict:
-			matrix.append(dict2matrix(obj[m]))
+			matrix.append([m, dict2matrix(obj[m])])
 		else:
-			matrix.append([obj[m]])
-	return matrix
+			matrix.append(Matrix([m, obj[m]]))
+	return Matrix(matrix)
 
 @appendAll
 def str2list(string):
@@ -480,13 +548,13 @@ def list2str(listObj, space=''):
 
 @appendAll
 def matrix2str(mat, space=''):
-	if not type(mat) == list:
-		raise TypeError('list object is required.')
+	if not type(mat) in [list, Matrix]:
+		raise TypeError('list or Matrix object is required.')
 	string = ''
 	for m in mat:
 		if string:
 			string += space
-		if type(m) == list:
+		if type(m) in [list, Matrix]:
 			string += str(matrix2str(m))
 		elif type(m) == dict:
 			string += str(matrix2str(dict2matrix(m)))
@@ -761,6 +829,8 @@ class Settings(object):
 		self._write()
 
 	def _write(self):
+		if 'light' in status:
+			return
 		global localSets
 		try:
 			self._file = open(settingFilePath, 'w')
